@@ -14,15 +14,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from cinderclient import api_versions
 from cinderclient.tests.unit import utils
 from cinderclient.tests.unit.v3 import fakes
 
-cs = fakes.FakeClient()
-
 
 class AttachmentsTest(utils.TestCase):
 
     def test_create_attachment(self):
+        cs = fakes.FakeClient(api_versions.APIVersion('3.27'))
         att = cs.attachments.create(
             'e84fda45-4de4-4ce4-8f39-fc9d3b0aa05e',
             {},
@@ -31,6 +31,6 @@ class AttachmentsTest(utils.TestCase):
         self.assertEqual(fakes.fake_attachment['attachment'], att)
 
     def test_complete_attachment(self):
-        att = cs.attachments.complete(
-            'a232e9ae')
+        cs = fakes.FakeClient(api_versions.APIVersion('3.44'))
+        att = cs.attachments.complete('a232e9ae')
         self.assertTrue(att.ok)
